function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        utm_campaign: urlParams.get('utm_campaign') || 'not_set',
        utm_content: urlParams.get('utm_content') || 'not_set',
        utm_medium: urlParams.get('utm_medium') || 'not_set',
        utm_source: urlParams.get('utm_source') || 'not_set',
        subid: urlParams.get('subid') || 'not_set'
    };
}

function appendParamsToURL(baseURL, debtAmount) {
    const currentParams = new URLSearchParams(window.location.search);
    currentParams.append('debt_amount', debtAmount);
    return `${baseURL}?${currentParams.toString()}`;
}

// Store the assigned number in localStorage
function savePhoneNumber(number) {
    localStorage.setItem('assignedPhone', JSON.stringify(number));
}

// Get stored number or return null
function getStoredNumber() {
    const stored = localStorage.getItem('assignedPhone');
    return stored ? JSON.parse(stored) : null;
}

// Update agent count with real random changes
function updateAgentCount() {
    const count = Math.floor(Math.random() * (7 - 4 + 1)) + 4;
    document.getElementById('agentCount').textContent = count;
}

// Call it once when DOM is ready
document.addEventListener('DOMContentLoaded', () => {
    updateAgentCount();
    startCountdown();
});

// Enhanced countdown timer
function startCountdown() {
    let timeLeft = 180;
    const countdownElement = document.getElementById('countdown');
    
    const timer = setInterval(() => {
        const minutes = Math.floor(timeLeft / 60);
        const seconds = timeLeft % 60;
        
        countdownElement.textContent = `${minutes}:${seconds.toString().padStart(2, '0')}`;
            
        if (timeLeft === 0) {
            timeLeft = 180; // Reset timer when it hits zero
        } else {
            timeLeft--;
        }
    }, 1000);
}

// Initialize TrackDrive immediately
(function() {
    const storedNumber = getStoredNumber();
    const callButton = document.querySelector('.btn');
    
    // Apply stored number immediately if available
    if (storedNumber && callButton) {
        callButton.href = `tel:${storedNumber.plain_number}`;
        callButton.innerHTML = `${storedNumber.human_number}`;
    }

    const urlParams = new URLSearchParams(window.location.search);
    urlParams.set('a', 'ccc');
    const newUrl = `${window.location.pathname}?${urlParams.toString()}`;
    window.history.replaceState({}, '', newUrl);
    
    const options = {
        offer_token: 'dba0dcc93c9e518a83ecd90ec209c5c8',
        default_number: {
            human_number: '(855) 654-2938',
            plain_number: '8556542938'
        },
        tokens: {
            utm_source: urlParams.get('utm_source') || '',
            utm_content: urlParams.get('utm_content') || '',
            utm_medium: urlParams.get('utm_medium') || '',
            utm_campaign: urlParams.get('utm_campaign') || '',
            s: urlParams.get('subid') || '',
            lp:urlParams.get('lpip') || '',
            o: urlParams.get('ofid') || '',
            a: 'ccc',
            aa: 'SC'

        }
    };

    if (typeof Trackdrive !== 'undefined') {
        Trackdrive.Optimizer.replace_all(options, [
            ["(855) 654-2938", "human_number"],
            ["8556542938", "plain_number"]
        ]);

        Trackdrive.Optimizer.on_number_assigned(function(number) {
            if (callButton) {
                callButton.href = `tel:${number.plain_number}`;
                callButton.innerHTML = `${number.human_number}`;
                savePhoneNumber(number);
            }
        });
    }
})();

// Start dynamic elements immediately
document.addEventListener('DOMContentLoaded', () => {
    updateAgentCount();
    startCountdown();
});

// Other initialization functions in window.onload
window.onload = () => {
    const moreButton = document.querySelector('[title="10K"]');
    const lessButton = document.querySelector('[title="-10K"]');
    
    if (moreButton) moreButton.href = appendParamsToURL('/ty1/', '10K');
    if (lessButton) lessButton.href = appendParamsToURL('/ty1/', '-10K');
}