let userIP = '';

// Fetch IP address
fetch('https://api.ipify.org?format=json')
    .then(response => response.json())
    .then(data => userIP = data.ip);


function calculateAge(dob) {
    const birthDate = new Date(dob);
    const today = new Date();
    let age = today.getFullYear() - birthDate.getFullYear();
    const monthDiff = today.getMonth() - birthDate.getMonth();
    if (monthDiff < 0 || (monthDiff === 0 && today.getDate() < birthDate.getDate())) {
        age--;
    }
    return age;
}

function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        source: urlParams.get('source'),
        ad_id: urlParams.get('ad_id'),
        campaign_name: urlParams.get('campaign_name'),
        ad_name: urlParams.get('ad_name'),
        adset_name: urlParams.get('adset_name'),
        subid: urlParams.get('subid')
    };
}

let currentQuestion = 1;
function showNextQuestion() {
    const currentQuestionElement = document.getElementById(`question${currentQuestion}`);
    if (currentQuestionElement) {
        currentQuestionElement.style.display = 'none';
    }
    currentQuestion++;
    updateURL(currentQuestion - 1);
    const nextQuestionElement = document.getElementById(`question${currentQuestion}`);
    if (nextQuestionElement) {
        nextQuestionElement.style.display = 'block';
    } else {
        const finalForm = document.getElementById('finalForm');
        if (finalForm) {
            finalForm.style.display = 'block';
            finalForm.scrollIntoView({ behavior: 'smooth', block: 'start' });
        }
    }
}

document.addEventListener('DOMContentLoaded', function() {
    setupPhoneInput();
    
    if (document.getElementById('address')) {
        const addressInput = document.getElementById('address');
        const autocomplete = new google.maps.places.Autocomplete(addressInput);
        
        autocomplete.addListener('place_changed', function() {
            const place = autocomplete.getPlace();
            let city = '', state = '';
            
            place.address_components.forEach(component => {
                if (component.types.includes('locality')) {
                    city = component.long_name;
                }
                if (component.types.includes('administrative_area_level_1')) {
                    state = component.short_name;
                }
            });
            
            document.getElementById('city').value = city;
            document.getElementById('state').value = state;
        });
    }

    if (window.location.pathname.includes('thankyou.html') || window.location.pathname.includes('dnq.html')) {
        const urlParams = new URLSearchParams(window.location.search);
        const formDataStr = urlParams.get('data');
        
        if (formDataStr) {
            const formData = JSON.parse(formDataStr);
            if (isQualifiedLead(formData) && typeof fbq !== 'undefined') {
                fbq('track', 'Lead');
                console.log('Qualified lead pixel fired on thank you page');
            }
        }
    } else {
        const disqualifyingAnswers = {
            'question1': 'yes',  // Currently receiving Social Security benefits
            'question2': 'no',   // Not out of work for at least a year
            'question3': 'no',   // Haven't worked 5 of last 10 years
            'question4': 'no',   // Not being treated by Medical Professional
            'question5': 'yes'   // Already has an attorney
        };

        const form = document.getElementById('userInfoForm');
        if (form) {
            form.addEventListener('click', function(e) {
                if (e.target.classList.contains('yes-no-button') ||
                    e.target.classList.contains('yes-no-button-alt')) {
                    const questionId = e.target.closest('.form-group').id;
                    const answer = e.target.getAttribute('data-value');
                    
                    // Check for disqualifying answers
                    if (disqualifyingAnswers[questionId] === answer) {
                        if (window.fathom) {
                            window.fathom.trackEvent('quiz_dnq');
                        }
                        window.location.href = 'https://www.claimyourbenefitsnow.com/';
                        return;
                    }

                    // Track quiz completion when reaching final question
                    if (questionId === 'question5' && window.fathom) {
                        window.fathom.trackEvent('quiz_complete');
                    }

                    e.target.closest('.yes-no-buttons, .yes-no-buttons-alt').querySelectorAll('button').forEach(btn => {
                        btn.classList.remove('selected');
                    });
                    e.target.classList.add('selected');
                    showNextQuestion();
                }
            });

            form.addEventListener('submit', async function(e) {
                e.preventDefault();
                const formData = new FormData(form);
                const data = Object.fromEntries(formData.entries());
                const jornayaToken = document.getElementById('leadid_token')?.value;
                const trustedFormCert = document.getElementById('xxTrustedFormCertUrl')?.value;
                const ghlData = {
                    firstName: data.firstName,
                    lastName: data.lastName,
                    email: data.email,
                    phone: data.phone,
                    age: data.age,
                    dob_year: calculateDOBYear(data.age),
                    dob: data.dob,
                    address: data.address,
                    city: data.cityInput,
                    state: data.state,
                    zipCode: data.zipCode,
                    ip_address: userIP,
                    userAgent: navigator.userAgent,
                    optin_url: 'betteramericanlives.com/ssdfl',
                    receiving_benefits: getSelectedValue('question1'),
                    out_of_work: getSelectedValue('question2'),
                    worked_five_years: getSelectedValue('question3'),
                    seen_doctor: getSelectedValue('question4'),
                    has_lawyer: getSelectedValue('question5'),
                    medical_condition: data.summary,
                    jornaya_lead_id: jornayaToken,
                    trusted_form_id: trustedFormCert,
                    timestamp: getPSTTimestamp(),
                    consent: document.querySelector('.disclaimer').innerText,
                    ...getUTMParameters()
                };
                
                function calculateDOBYear(age) {
                    const currentYear = new Date().getFullYear();
                    return currentYear - parseInt(age);
                }
                
                postToGHL(ghlData);
            });        }
    }
});

function isQualifiedLead(data) {
    return (
        data.receiving_benefits === 'no' &&
        data.out_of_work === 'yes' &&
        data.worked_five_years === 'yes' &&
        data.seen_doctor === 'yes' &&
        data.has_lawyer === 'no'
    );
}

function postToGHL(data) {
    const isQualified = isQualifiedLead(data);

    if (window.fathom) {
        if (isQualified) {
            window.fathom.trackEvent('lead');
        } else {
            window.fathom.trackEvent('dnq');
        }
    }

    if (isQualified && typeof fbq !== 'undefined') {
        fbq('track', 'Lead');
        console.log('Facebook lead pixel fired');
    }

    $.post("post.php", data,
        function(data, status){
        console.log(data);
        if (data.trim() == "") {
            window.location.href = 'thankyou.html';
        } else {
            window.location.href = data;
        }
        return;
    });

    /*
    fetch('https://services.leadconnectorhq.com/hooks/hDuW5BJtfaLU5bTBefY8/webhook-trigger/65OK13OUTiWtG1sqvY5a', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(data)
    })
    .then(response => response.json())
    .then(responseData => {
        console.log('Success:', responseData);
        const allData = { ...data, ghlResponse: responseData };
        window.location.href = isQualified ? 'thankyou.html' : 'dnq.html?' + new URLSearchParams({data: JSON.stringify(allData)}).toString();
    })
    .catch((error) => {
        console.error('Error:', error);
        window.location.href = isQualified ? 'thankyou.html' : 'dnq.html';
    });
    */
}

function getSelectedValue(questionId) {
    const selectedButton = document.querySelector(`#${questionId} .yes-no-button.selected`);
    return selectedButton ? selectedButton.getAttribute('data-value') : '';
}

function updateURL(questionNumber) {
    const url = new URL(window.location);
    url.searchParams.set('q', questionNumber);
    window.history.pushState({}, '', url);
}
function setupPhoneInput() {
    const phoneInput = document.getElementById('phone');
    if (!phoneInput) return;
    
    phoneInput.addEventListener('input', function(e) {
        let value = e.target.value.replace(/\D/g, '');
        value = value.substring(0, 14);
        phoneInput.value = value;
    });
}function setupAgeInput() {
    const ageInput = document.getElementById('age');
    ageInput.addEventListener('input', function(e) {
        let value = e.target.value.replace(/\D/g, '');
        value = value.substring(0, 2);
        ageInput.value = value;
    });
}

const zipToState = {
    "00": "PR", "01": "MA", "02": "MA", "03": "NH", "04": "ME", "05": "VT", "06": "CT", "07": "NJ",
    "08": "NJ", "09": "PR", "10": "NY", "11": "NY", "12": "NY", "13": "NY", "14": "NY", "15": "PA",
    "16": "PA", "17": "PA", "18": "PA", "19": "PA", "20": "DC", "21": "MD", "22": "VA", "23": "VA",
    "24": "VA", "25": "WV", "26": "WV", "27": "NC", "28": "NC", "29": "SC", "30": "GA", "31": "GA",
    "32": "FL", "33": "FL", "34": "FL", "35": "AL", "36": "AL", "37": "TN", "38": "TN", "39": "MS",
    "40": "KY", "41": "KY", "42": "KY", "43": "OH", "44": "OH", "45": "OH", "46": "IN", "47": "IN",
    "48": "MI", "49": "MI", "50": "IA", "51": "IA", "52": "IA", "53": "WI", "54": "WI", "55": "MN",
    "56": "MN", "57": "SD", "58": "ND", "59": "MT", "60": "IL", "61": "IL", "62": "IL", "63": "MO",
    "64": "MO", "65": "MO", "66": "KS", "67": "KS", "68": "NE", "69": "NE", "70": "LA", "71": "LA",
    "72": "AR", "73": "OK", "74": "OK", "75": "TX", "76": "TX", "77": "TX", "78": "TX", "79": "TX",
    "80": "CO", "81": "CO", "82": "WY", "83": "ID", "84": "UT", "85": "NM", "86": "AZ", "87": "NM",
    "88": "NM", "89": "NV", "90": "CA", "91": "CA", "92": "CA", "93": "CA", "94": "CA", "95": "CA",
    "96": "CA", "97": "OR", "98": "WA", "99": "WA"
};

function setupZipCodeInput() {
    const zipInput = document.getElementById('zipCode');
    if (!zipInput) return;
    
    zipInput.addEventListener('input', function(e) {
        let value = e.target.value.replace(/\D/g, '');
        value = value.substring(0, 5);
        zipInput.value = value;
        
        if (value.length === 5) {
            const statePrefix = value.substring(0, 2);
            const state = zipToState[statePrefix];
            document.getElementById('state').value = state || '';
        }
    });
}
document.addEventListener('DOMContentLoaded', function() {
    setupPhoneInput();
    setupAgeInput();
    setupZipCodeInput();
});

const ctaButton = document.querySelector('.cta-button');
if (ctaButton) {
    ctaButton.addEventListener('click', function() {
        const formContainer = document.querySelector('.form-container');
        if (formContainer) {
            formContainer.scrollIntoView({
                behavior: 'smooth',
                block: 'center'
            });
        }
    });
}

function getPSTTimestamp() {
    const now = new Date();
    const pstDate = new Date(now.toLocaleString("en-US", {timeZone: "America/Los_Angeles"}));
    const hours = pstDate.getHours();
    const minutes = pstDate.getMinutes();
    const ampm = hours >= 12 ? 'PM' : 'AM';
    const formattedHours = hours % 12 || 12;
    const formattedMinutes = minutes < 10 ? '0' + minutes : minutes;
    return `${formattedHours}:${formattedMinutes} ${ampm}`;
}