let userIP = '';
let phoneIsValid = false;
let preQuestion = 1;

// Fetch IP address
fetch('https://api.ipify.org?format=json')
    .then(response => response.json())
    .then(data => userIP = data.ip);

function calculateAge(dob) {
    const birthDate = new Date(dob);
    const today = new Date();
    let age = today.getFullYear() - birthDate.getFullYear();
    const monthDiff = today.getMonth() - birthDate.getMonth();
    if (monthDiff < 0 || (monthDiff === 0 && today.getDate() < birthDate.getDate())) {
        age--;
    }
    return age;
}

function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        source: urlParams.get('source'),
        ad_id: urlParams.get('ad_id'),
        campaign_name: urlParams.get('campaign_name'),
        ad_name: urlParams.get('ad_name'),
        adset_name: urlParams.get('adset_name'),
        subid: urlParams.get('subid')
    };
}

let currentQuestion = 1;

function showNextQuestion() {
    const currentQuestionElement = document.getElementById(`question${currentQuestion}`);
    if (currentQuestionElement) {
        currentQuestionElement.style.display = 'none';
    }
    currentQuestion++;
    updateURL(currentQuestion - 1);
    const nextQuestionElement = document.getElementById(`question${currentQuestion}`);
    if (nextQuestionElement) {
        nextQuestionElement.style.display = 'block';
    } else {
        const finalForm = document.getElementById('finalForm');
        if (finalForm) {
            finalForm.style.display = 'block';
            finalForm.scrollIntoView({ behavior: 'smooth', block: 'start' });
        }
    }
}

document.addEventListener('DOMContentLoaded', function() {
    // Show qualification questions right away
    document.querySelector('.qualification-questions').style.display = 'block';
    document.getElementById('question1').style.display = 'block';
    
    // Phone validation
    $('#phone').on('input', function() {
        const phoneNumber = $(this).val();
        if (phoneNumber.length >= 10) {
            $.ajax({
                url: 'verify-phone.php',
                data: { phone: phoneNumber },
                success: function(response) {
                    const data = typeof response === 'string' ? JSON.parse(response) : response;
                    phoneIsValid = data.status === 'valid';
                    $('#phone').css('border', '2px solid ' + (phoneIsValid ? '#28a745' : '#dc3545'));
                }
            });
        }
    });

    const disqualifyingAnswers = {
        'question1': 'yes',
        'question2': 'no',
        'question3': 'no',
        'question4': 'no',
        'question5': 'yes'
    };

    const form = document.getElementById('userInfoForm');
    if (form) {
        // Your existing click handler for yes/no buttons
        form.addEventListener('click', function(e) {
            if (e.target.classList.contains('yes-no-button') ||
                e.target.classList.contains('yes-no-button-alt')) {
                const questionId = e.target.closest('.form-group').id;
                
                const answer = e.target.getAttribute('data-value');
                
                if (disqualifyingAnswers[questionId] === answer) {
                    if (window.fathom) {
                        window.fathom.trackEvent('quiz_dnq');
                    }
                    window.location.href = 'https://www.claimyourbenefitsnow.com/';
                    return;
                }

                if (questionId === 'question5' && window.fathom) {
                    window.fathom.trackEvent('quiz_complete');
                }

                e.target.closest('.yes-no-buttons, .yes-no-buttons-alt')
                    .querySelectorAll('button')
                    .forEach(btn => btn.classList.remove('selected'));
                e.target.classList.add('selected');
                showNextQuestion();
            }
        });

        // Form submission handler
        form.addEventListener('submit', async function(e) {
            e.preventDefault();
            
            if (!phoneIsValid) {
                alert('Please enter valid phone');
                return;
            }

            const formData = new FormData(form);
            const data = Object.fromEntries(formData.entries());
            
            const jornayaToken = document.getElementById('leadid_token')?.value || '';
            const trustedFormCert = document.querySelector('input[name="xxTrustedFormCertUrl"]')?.value || '';

            const ghlData = {
                firstName: data.firstName,
                lastName: data.lastName,
                email: data.email,
                phone: data.phone,
                ip: userIP,
                userAgent: navigator.userAgent,
                landingPage: 'monthlyssdi.com/lander2',
                receiving_benefits: getSelectedValue('question1'),
                out_of_work: getSelectedValue('question2'),
                worked_five_years: getSelectedValue('question3'),
                seen_doctor: getSelectedValue('question4'),
                has_lawyer: getSelectedValue('question5'),
                universal_leadid: jornayaToken,
                trusted_form_id: trustedFormCert,
                ad_account: 'SC',
                timestamp: getPSTTimestamp(),
                ...getUTMParameters()
            };

            await postToGHL(ghlData);
        });
    }
});

function isQualifiedLead(data) {
    return (
        data.receiving_benefits === 'no' &&
        data.out_of_work === 'yes' &&
        data.worked_five_years === 'yes' &&
        data.seen_doctor === 'yes' &&
        data.has_lawyer === 'no'
    );
}

function postToGHL(data) {
    const isQualified = isQualifiedLead(data);

    if (window.fathom) {
        if (isQualified) {
            window.fathom.trackEvent('lead');
        } else {
            window.fathom.trackEvent('dnq');
        }
    }

    fetch('https://services.leadconnectorhq.com/hooks/hDuW5BJtfaLU5bTBefY8/webhook-trigger/d8d50cff-eb6c-4ee1-bc20-7c4ea6dbe36f', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(data)
    })
    .then(response => response.json())
    .then(responseData => {
        console.log('Success:', responseData);
        const allData = { ...data, ghlResponse: responseData };
        window.location.href = isQualified ? 
            'https://get.monthlyssdi.com/base2.php' : 
            'dnq.html?' + new URLSearchParams({data: JSON.stringify(allData)}).toString();
    })
    .catch((error) => {
        console.error('Error:', error);
        window.location.href = isQualified ? 
            'https://get.monthlyssdi.com/base2.php' : 
            'dnq.html';
    });
}

function getSelectedValue(questionId) {
    const selectedButton = document.querySelector(`#${questionId} .yes-no-button.selected`);
    return selectedButton ? selectedButton.getAttribute('data-value') : '';
}

function updateURL(questionNumber) {
    const url = new URL(window.location);
    url.searchParams.set('q', questionNumber);
    window.history.pushState({}, '', url);
}

document.querySelector('.cta-button').addEventListener('click', function() {
    const formContainer = document.querySelector('.form-container');
    formContainer.scrollIntoView({
        behavior: 'smooth',
        block: 'center'
    });
});

function getPSTTimestamp() {
    const now = new Date();
    const pstDate = new Date(now.toLocaleString("en-US", {timeZone: "America/Los_Angeles"}));
    const hours = pstDate.getHours();
    const minutes = pstDate.getMinutes();
    const ampm = hours >= 12 ? 'PM' : 'AM';
    const formattedHours = hours % 12 || 12;
    const formattedMinutes = minutes < 10 ? '0' + minutes : minutes;
    return `${formattedHours}:${formattedMinutes} ${ampm}`;
}