// Function to get URL parameters
function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        utm_campaign: urlParams.get('utm_campaign') || 'not_set',
        utm_content: urlParams.get('utm_content') || 'not_set',
        utm_medium: urlParams.get('utm_medium') || 'not_set',
        utm_source: urlParams.get('utm_source') || 'not_set',
        subid: urlParams.get('subid') || 'not_set'
    };
}

$(document).ready(function () {
    console.log("URL Parameters:", getUTMParameters());

    // --- Qualification Popup Logic (Variables needed in button handler) ---
    const popupElement = $('#qualification-popup');
    let popupDismissed = false; // Make sure this is accessible
    let popupIntervalId = null; // Make sure this is accessible
    let popupTimeoutId = null; // Make sure this is accessible

    function hidePopup() { // Ensure hidePopup function is defined before use or accessible
         popupElement.removeClass('popup-visible').addClass('popup-hidden');
    }
    // ... (rest of popup setup code like people array, other functions) ...

    // --- End Qualification Popup Logic Setup ---


    // Initial Claim Question Handler (Now First)
    $('.initial-claim-btn').on('click', function() {
        // ADDED: Hide initial content elements
        $('.bner').hide();
        $('.info-text').hide(); // Hides paragraphs and ordered list
        $('.yui').hide(); // Hides the main heading

        $('#initial-claim-question').hide();
        $('#question-medical-condition').show(); // Show Medical Condition question next

        // --- ADDED: Stop the popup ---
        if (!popupDismissed) { // Only do this if not already dismissed
            console.log("Initial button clicked, stopping popup.");
            hidePopup(); // Hide if currently visible
            popupDismissed = true; // Prevent future popups
            if (popupIntervalId) clearInterval(popupIntervalId); // Stop the interval timer
            if (popupTimeoutId) clearTimeout(popupTimeoutId); // Stop any pending show timeout
        }
        // --- End Stop Popup Logic ---
    });

    // Medical Condition Question (Now Second)
    $('.medical-condition-btn').on('click', function() {
        const hasCondition = $(this).data('answer');
        if (hasCondition === 'no') {
            handleRedirect('dq');
        } else {
            $('#question-medical-condition').hide();
            $('#question-2').show(); // Show SSDI Benefits question next
        }
    });

    // SSDI Benefits Question (Question 2 -> Now Third in sequence)
    $('.ssdi-benefits-btn').on('click', function() {
        const receivingBenefits = $(this).data('answer');
        if (receivingBenefits === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-2').hide();
            $('#question-3').show(); // Show Working Status question
        }
    });

    // Working Status Question (Question 3 -> Now Fourth)
    $('.working-status-btn').on('click', function() {
        const isWorking = $(this).data('answer');
        if (isWorking === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-3').hide();
            $('#question-4').show(); // Show Attorney question
        }
    });

    // Attorney Question (Question 4 -> Now Fifth)
    $('.attorney-status-btn').on('click', function() {
        const hasAttorney = $(this).data('answer');
        if (hasAttorney === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-4').hide();
            $('#question-5').show(); // Show Doctor Status question
        }
    });

    // Doctor Status Question (Question 5 -> Now Sixth)
    $('.doctor-status-btn').on('click', function() {
        const seeingDoctor = $(this).data('answer');
        if (seeingDoctor === 'no') {
            handleRedirect('dq');
        } else {
            $('#question-5').hide();
            $('#question-6').show(); // Show Work History question
        }
    });

    // Work History Question (Question 6 -> Now Last)
    $('.work-history-btn').on('click', function() {
        const hasWorkHistory = $(this).data('answer');
        if (hasWorkHistory === 'no') {
            handleRedirect('dq');
        } else {
            handleRedirect('qualified'); // User is qualified
        }
    });

    // --- Qualification Popup Initialization (Keep this part) ---
    const people = [
        // Updated names more common for 50-60 age range
        { name: "Lisa", image: "ashley.png" },     // Placeholder image
        { name: "Michael", image: "brian.png" },    // Placeholder image
        { name: "Susan", image: "chloe.png" },     // Placeholder image
        { name: "David", image: "david.png" },     // Placeholder image
        { name: "Karen", image: "emily.png" },     // Placeholder image
        { name: "Robert", image: "frank.png" },    // Placeholder image
        { name: "Jennifer", image: "grace.png" },   // Placeholder image
        { name: "James", image: "henry.png" },     // Placeholder image
        { name: "Michelle", image: "isabella.png" },// Placeholder image
        { name: "Christopher", image: "jacob.png" } // Placeholder image
        // Note: Image filenames are kept as placeholders; update if you have matching images
    ];

    const popupImage = $('#popup-image');
    const popupMessage = $('#popup-message');
    function getRandomAmount(min, max) {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }

    function formatCurrency(amount) {
        return amount.toLocaleString('en-US', { style: 'currency', currency: 'USD', minimumFractionDigits: 0, maximumFractionDigits: 0 });
    }

    function showPopup(person, amount) {
        if (popupDismissed) return;

        const formattedAmount = formatCurrency(amount);
        popupImage.attr('src', `img/${person.image}`); // Assuming images are in an 'img' folder
        popupImage.attr('alt', person.name);
        popupMessage.html(`${person.name} qualified for <strong>${formattedAmount}</strong> in monthly disability benefits!`); // Use .html() to render <strong>

        popupElement.removeClass('popup-hidden').addClass('popup-visible');
    }

    function hidePopup() {
         popupElement.removeClass('popup-visible').addClass('popup-hidden');
    }

    function cyclePopup() {
        if (popupDismissed) {
            if (popupIntervalId) clearInterval(popupIntervalId);
            return;
        }

        // Hide briefly before showing the next one
        if (popupElement.hasClass('popup-visible')) {
            hidePopup();
        }

        // Clear any existing timeout to prevent race conditions
        if (popupTimeoutId) clearTimeout(popupTimeoutId);

        // Wait a moment after hiding, then show the new one
        popupTimeoutId = setTimeout(() => {
            if (popupDismissed) return; // Check again in case dismissed during timeout

            const randomIndex = Math.floor(Math.random() * people.length);
            const randomPerson = people[randomIndex];
            const randomAmount = getRandomAmount(3848, 4038); // Range $3,848 - $4,038

            showPopup(randomPerson, randomAmount);

        }, 600); // Delay slightly longer than CSS transition
    }

    // Click listener for the popup itself
    popupElement.on('click', function() {
        hidePopup();
        popupDismissed = true;
        if (popupIntervalId) clearInterval(popupIntervalId); // Stop the interval
        if (popupTimeoutId) clearTimeout(popupTimeoutId); // Stop any pending show
        console.log("Popup dismissed by user.");
    });

    // Start the cycle
    setTimeout(cyclePopup, 2000); // Initial delay before first popup
    popupIntervalId = setInterval(cyclePopup, 5000 + 600); // 5s + hide/show delay
    // --- End Qualification Popup Initialization ---
}); // End of $(document).ready()

function handleRedirect(status, page = '/dq') { // Default DQ page
    const params = getUTMParameters();

    // For DQ cases
    if (status === 'dq') {
        // Construct DQ URL with parameters if needed, or just redirect
        // Example: window.location.href = `${page}?${new URLSearchParams(params).toString()}`;
        window.location.href = page; // Simple redirect for now
        return;
    }

    // For qualified cases
    if (status === 'qualified') {
        const baseUrl = 'https://get.monthlyssdi.com/base2.php';
        const queryString = Object.entries(params)
            .filter(([key, value]) => value !== 'not_set' && value !== null && value !== undefined) // Filter out unset params
            .map(([key, value]) => `${encodeURIComponent(key)}=${encodeURIComponent(value)}`)
            .join('&');

        window.location.href = `${baseUrl}?${queryString}`;
        return;
    }

    // Fallback or error handling if needed
    console.error("handleRedirect called with unknown status:", status);
}
