// Function to get URL parameters
function getUTMParameters() {
    const urlParams = new URLSearchParams(window.location.search);
    return {
        utm_campaign: urlParams.get('utm_campaign') || 'not_set',
        utm_content: urlParams.get('utm_content') || 'not_set',
        utm_medium: urlParams.get('utm_medium') || 'not_set',
        utm_source: urlParams.get('utm_source') || 'not_set',
        subid: urlParams.get('subid') || 'not_set'
    };
}

$(document).ready(function () {
    console.log("URL Parameters:", getUTMParameters());

    // Initial Claim Question Handler (Now First)
    $('.initial-claim-btn').on('click', function() {
        // ADDED: Hide initial content elements
        $('.bner').hide();
        $('.info-text').hide(); // Hides paragraphs and ordered list
        $('.yui').hide(); // Hides the main heading

        $('#initial-claim-question').hide();
        $('#question-medical-condition').show(); // Show Medical Condition question next
    });

    // Medical Condition Question (Now Second)
    $('.medical-condition-btn').on('click', function() {
        const hasCondition = $(this).data('answer');
        if (hasCondition === 'no') {
            handleRedirect('dq');
        } else {
            $('#question-medical-condition').hide();
            $('#question-2').show(); // Show SSDI Benefits question next
        }
    });

    // SSDI Benefits Question (Question 2 -> Now Third in sequence)
    $('.ssdi-benefits-btn').on('click', function() {
        const receivingBenefits = $(this).data('answer');
        if (receivingBenefits === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-2').hide();
            $('#question-3').show(); // Show Working Status question
        }
    });

    // Working Status Question (Question 3 -> Now Fourth)
    $('.working-status-btn').on('click', function() {
        const isWorking = $(this).data('answer');
        if (isWorking === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-3').hide();
            $('#question-4').show(); // Show Attorney question
        }
    });

    // Attorney Question (Question 4 -> Now Fifth)
    $('.attorney-status-btn').on('click', function() {
        const hasAttorney = $(this).data('answer');
        if (hasAttorney === 'yes') {
            handleRedirect('dq');
        } else {
            $('#question-4').hide();
            $('#question-5').show(); // Show Doctor Status question
        }
    });

    // Doctor Status Question (Question 5 -> Now Sixth)
    $('.doctor-status-btn').on('click', function() {
        const seeingDoctor = $(this).data('answer');
        if (seeingDoctor === 'no') {
            handleRedirect('dq');
        } else {
            $('#question-5').hide();
            $('#question-6').show(); // Show Work History question
        }
    });

    // Work History Question (Question 6 -> Now Last)
    $('.work-history-btn').on('click', function() {
        const hasWorkHistory = $(this).data('answer');
        if (hasWorkHistory === 'no') {
            handleRedirect('dq');
        } else {
            handleRedirect('qualified'); // User is qualified
        }
    });
});

function handleRedirect(status, page = '/dq') { // Default DQ page
    const params = getUTMParameters();

    // For DQ cases
    if (status === 'dq') {
        // Construct DQ URL with parameters if needed, or just redirect
        // Example: window.location.href = `${page}?${new URLSearchParams(params).toString()}`;
        window.location.href = page; // Simple redirect for now
        return;
    }

    // For qualified cases
    if (status === 'qualified') {
        const baseUrl = 'https://get.monthlyssdi.com/base2.php';
        const queryString = Object.entries(params)
            .filter(([key, value]) => value !== 'not_set' && value !== null && value !== undefined) // Filter out unset params
            .map(([key, value]) => `${encodeURIComponent(key)}=${encodeURIComponent(value)}`)
            .join('&');

        window.location.href = `${baseUrl}?${queryString}`;
        return;
    }

    // Fallback or error handling if needed
    console.error("handleRedirect called with unknown status:", status);
}
